@@ -1,5 +1,8 @@
 from commonutils import StaticUtils
 from copy import deepcopy
+from .basetab import BaseTab
+from .config import Config
+from .staticutils import StaticUtils
 from .ttk.smartwidget import SmartWidget
 
 class SmartWidgetProxy:
